==> icecat-3.5.1.tar.bz2: icecat-3.5.1/accessible/src/msaa/CAccessibleComponent.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:expandtab:shiftwidth=2:tabstop=2:
 */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Mozilla Foundation.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Alexander Surkov <surkov.alexander@gmail.com> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef _ACCESSIBLE_COMPONENt_H
#define _ACCESSIBLE_COMPONENT_H

#include "nsISupports.h"

#include "AccessibleComponent.h"

class CAccessibleComponent: public nsISupports,
                            public IAccessibleComponent
{
public:

  // IUnknown
  STDMETHODIMP QueryInterface(REFIID, void**);

  // IAccessibleComponent
  virtual /* [propget] */ HRESULT STDMETHODCALLTYPE get_locationInParent(
      /* [out] */ long *x,
      /* [retval][out] */ long *y);

  virtual /* [propget] */ HRESULT STDMETHODCALLTYPE get_foreground(
      /* [retval][out] */ IA2Color *foreground);

  virtual /* [propget] */ HRESULT STDMETHODCALLTYPE get_background(
      /* [retval][out] */ IA2Color *background);

protected:

  /**
   * Return ARGB value for CSS property like 'color' or 'background-color'.
   */
  HRESULT GetARGBValueFromCSSProperty(const nsAString& aPropName,
                                      IA2Color *aColorValue);
};

#endif

==> icecat-4.0.tar.bz2: icecat-4.0/accessible/src/msaa/CAccessibleComponent.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:expandtab:shiftwidth=2:tabstop=2:
 */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Mozilla Foundation.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Alexander Surkov <surkov.alexander@gmail.com> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef _ACCESSIBLE_COMPONENt_H
#define _ACCESSIBLE_COMPONENT_H

#include "nsISupports.h"

#include "AccessibleComponent.h"

class CAccessibleComponent: public IAccessibleComponent
{
public:

  // IUnknown
  STDMETHODIMP QueryInterface(REFIID, void**);

  // IAccessibleComponent
  virtual /* [propget] */ HRESULT STDMETHODCALLTYPE get_locationInParent(
      /* [out] */ long *x,
      /* [retval][out] */ long *y);

  virtual /* [propget] */ HRESULT STDMETHODCALLTYPE get_foreground(
      /* [retval][out] */ IA2Color *foreground);

  virtual /* [propget] */ HRESULT STDMETHODCALLTYPE get_background(
      /* [retval][out] */ IA2Color *background);

  // nsISupports
  NS_IMETHOD QueryInterface(const nsIID& uuid, void** result) = 0;

protected:

  /**
   * Return ARGB value for CSS property like 'color' or 'background-color'.
   */
  HRESULT GetARGBValueFromCSSProperty(const nsAString& aPropName,
                                      IA2Color *aColorValue);
};

#endif
